==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageEventArgsDetailDescriptionMetadata } from "./WebPageEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDescription } from "./WebPageEventArgsDescription";
/**
 * @hidden
 */
export let WebPageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageEventArgsDescriptionMetadata.a == null) {
                WebPageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageEventArgsDescriptionMetadata.c(WebPageEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPageEventArgsDescriptionMetadata.a);
            WebPageEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPageEventArgsDetail");
        }
        static d(a) {
            WebPageEventArgsDescriptionMetadata.b(a);
            a.ad("WebPageEventArgs", () => new WebPageEventArgsDescription());
            a.ac("WebPageEventArgs", WebPageEventArgsDescriptionMetadata.a);
        }
    }
    WebPageEventArgsDescriptionMetadata.$t = markType(WebPageEventArgsDescriptionMetadata, 'WebPageEventArgsDescriptionMetadata');
    WebPageEventArgsDescriptionMetadata.a = null;
    return WebPageEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageEventArgsDetailDescriptionMetadata } from "./WebPageEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDescription } from "./WebPageEventArgsDescription";
/**
 * @hidden
 */
export let WebPageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageEventArgsDescriptionMetadata.a == null) {
                WebPageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageEventArgsDescriptionMetadata.c(WebPageEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPageEventArgsDescriptionMetadata.a);
            WebPageEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPageEventArgsDetail");
        }
        static d(a) {
            WebPageEventArgsDescriptionMetadata.b(a);
            a.ae("WebPageEventArgs", () => new WebPageEventArgsDescription());
            a.ad("WebPageEventArgs", WebPageEventArgsDescriptionMetadata.a);
        }
    }
    WebPageEventArgsDescriptionMetadata.$t = markType(WebPageEventArgsDescriptionMetadata, 'WebPageEventArgsDescriptionMetadata');
    WebPageEventArgsDescriptionMetadata.a = null;
    return WebPageEventArgsDescriptionMetadata;
})();
